==> vQMgArq1o4U1-0.0.17.tgz: package/http-worker.js <==
const http = require('http');
const sandbox = require('./sandbox.js')

console.log('starting worker: ' , process.pid );

var server = http.createServer(function(req, response ) {

    //send the process id for timeout function
    process.send(process.pid)

    var body = '';
    req.on('data', function (data) {
      console.log('http-worker.js - request buffer received ', data)
      body += data;
    });

    req.on('end', function () {
      console.log("http-worker - request - Body: ", body);
      try{
        var scriptObj = JSON.parse( body )

        sandbox( scriptObj.script , scriptObj.libs , scriptObj.context, function(err, res ){
          //ask master to clear the master timeout, so the process doesn't end
          process.send( "clearTimeout");

          if ( err ){
            response.writeHead(500, { 'Content-Type': 'application/json'});
          }else{
            response.writeHead( 200, { 'Content-Type': 'application/json'});
          }

          var output = res || err
          response.write( JSON.stringify( output ) ); // errors were not being reported
          response.end()
        });
      }catch(e){
        console.log('http-worker.js - sandbox - error', e );
      }
    });
}).listen(8000);

server.on('clientError', (err, socket) => {
  console.log('http-worker.js - clientError - bad request', err);
  // socket.end('HTTP/1.1 400 Bad Request\r\n\r\n');
});

server.on('request', function (data) {
  console.log('http-worker.js - request message  ', data)
});


server.on('listening', function(){
  console.log('http-worker.js - server listening ')
  process.send( 'ready' );
});

==> vQMgArq1o4U1-0.0.19.tgz: package/http-worker.js <==
const http = require('http');
const sandbox = require('./sandbox.js')

console.log('starting worker: ' , process.pid );

var server = http.createServer(function(req, response ) {

    //send the process id for timeout function
    process.send(process.pid)

    var body = '';
    req.on('data', function (data) {
      console.log('http-worker.js - request buffer received ', data)
      body += data;
    });

    req.on('end', function () {
      console.log("http-worker - request - Body: ", body);
      try{
        var scriptObj = JSON.parse( body )

        sandbox( scriptObj.script , scriptObj.libs , scriptObj.context, function(err, res ){
          //ask master to clear the master timeout, so the process doesn't end
          process.send( "clearTimeout");

          if ( err ){
            response.writeHead(500, { 'Content-Type': 'application/json'});
          }else{
            response.writeHead( 200, { 'Content-Type': 'application/json'});
          }

          var output = res || err
          response.write( JSON.stringify( output ) ); // errors were not being reported
          response.end()
        });
      }catch(e){
        console.log('http-worker.js - sandbox - error', e );
      }
    });
}).listen(8000);

server.on('clientError', (err, socket) => {
  console.log('http-worker.js - clientError - bad request', err);
  // socket.end('HTTP/1.1 400 Bad Request\r\n\r\n');
});

// server.on('request', function (data) {
//   console.log('http-worker.js - request message  ', data)
// });


server.on('listening', function(){
  console.log('http-worker.js - server listening ')
  process.send( 'ready' );
});
